# API documentation

```{eval-rst}
.. currentmodule:: zospy

.. autosummary::
   :toctree: api
   :template: custom-module.rst
   :recursive:

   zpcore
   analyses
   analyses.old
   api.constants
   api.codecs
   functions
   solvers
```